NIDM-Results export
===================

Python toolbox to write out neuroimaging statistical results using the NeuroImaging Data
Model (NIDM Results: `specification`_, `manuscript`_).

.. _specification: http://nidm.nidash.org/specs/nidm-results.html
.. _manuscript: https://dx.doi.org/10.1038/sdata.2016.102
